#!perl
use strict;
use warnings;
use Test::More tests => 1;

# This test is here so that smoke testers run at least one test and do not
# complain: UNKNOWN: no tests run
#
# I do *not* want to have smoke testers not test this, because if a smoke
# tester wants, he can easily set up his rig to smoke this properly.
ok(1);

